@@ -135,6 +135,7 @@ class LScli extends LSlog_staticLoggerClass {
     $console_log = false;
     $quiet = false;
     $ldap_server_id = false;
+    $ldap_server_subDn = false;
     $command = false;
     $command_args = array();
     self :: log_debug("handle_args :\n".varDump($argv));
@@ -174,6 +175,10 @@ class LScli extends LSlog_staticLoggerClass {
             if(!LSsession :: setLdapServer($ldap_server_id))
               self :: usage("Fail to select LDAP server #$ldap_server_id.");
             break;
+          case '--sub-dn':
+            $i++;
+            $ldap_server_subDn = $argv[$i];
+            break;
           case '-L':
           case '--load-class':
             $i++;
@@ -216,6 +221,24 @@ class LScli extends LSlog_staticLoggerClass {
       // - otherwise: log only errors
       LSlog :: logOnConsole(($console_log?$log_level:'ERROR'));
 
+    // If no LDAP server subDn selected, check if current LDAP server need it,
+    // and select the first one
+    if (!$ldap_server_subDn) {
+      self :: need_ldap_con();
+      $subDns = LSsession :: getSubDnLdapServer();
+      if (is_array($subDns)) {
+        asort($subDns);
+        $ldap_server_subDn = key($subDns);
+      }
+    }
+
+    // Select LDAP server subDn (if need)
+    if ($ldap_server_subDn) {
+      self :: need_ldap_con();
+      if(!LSsession :: setSubDn($ldap_server_subDn))
+        self :: usage("Fail to select sub DN '$ldap_server_subDn'.");
+    }
+
     if (!$command) {
       self :: log_debug("LScli :: handle_args() : no detected command => show usage");
       self :: usage();
@@ -386,6 +409,8 @@ class LScli extends LSlog_staticLoggerClass {
     $command = null;
     $command_arg_num = null;
     $command_args = array();
+    $ldap_server_id = false;
+    $ldap_server_subDn = false;
     for ($i=1; $i < count($comp_words); $i++) {
       $unescaped_comp_word = $comp_words[$i];
       self :: unquote_word($unescaped_comp_word);
@@ -417,6 +442,25 @@ class LScli extends LSlog_staticLoggerClass {
                 self :: usage("Fail to select LDAP server #$ldap_server_id.");
             }
             break;
+          case '--sub-dn':
+            $i++;
+            if ($i == $comp_word_num) {
+              self :: need_ldap_con();
+              $subDns = LSsession :: getSubDnLdapServer();
+              if (!is_array($subDns))
+                $subDns = array();
+              return self :: return_bash_autocomplete_list(
+                self :: autocomplete_opts(array_keys($subDns), $comp_word)
+              );
+            }
+            if (!isset($comp_words[$i]))
+              break;
+            $ldap_server_subDn = $comp_words[$i];
+            self :: unquote_word($ldap_server_subDn);
+            self :: need_ldap_con();
+            if(!LSsession :: setSubDn($ldap_server_subDn))
+              self :: usage("Fail to select sub DN '$ldap_server_subDn'.");
+            break;
           case '-L':
           case '--load-class':
             $i++;
@@ -455,6 +499,19 @@ class LScli extends LSlog_staticLoggerClass {
       }
     }
 
+    // Is no subDn selected, check if LDAP server has subDn and select the first one if true
+    if (!$ldap_server_subDn) {
+      self :: need_ldap_con();
+      $subDns = LSsession :: getSubDnLdapServer();
+      if (is_array($subDns)) {
+        asort($subDns);
+        $subDn = key($subDns);
+        if(!LSsession :: setSubDn($subDn))
+          self :: usage("Fail to select sub DN '$subDn'.");
+        $opts[] = '--sub-dn';
+      }
+    }
+
     // If command set and args autocompleter defined, use it
     if ($command && is_callable(self :: $commands[$command]['args_autocompleter'])) {
       $command_comp_word_num = $comp_word_num-$command_arg_num-1;
@@ -593,26 +650,46 @@ class LScli extends LSlog_staticLoggerClass {
    * @retval array List of available options
    **/
   public static function autocomplete_LSobject_types($prefix='', $case_sensitive=true, $quote_char='') {
-    $types = LSconfig :: get('LSaccess', array(), null, LSsession :: $ldapServer);
     $subdn_config = LSconfig :: get('subDn', null, null, LSsession :: $ldapServer);
     if (is_array($subdn_config)) {
-      foreach ($subdn_config as $key => $value) {
-        if (!is_array($value)) continue;
-        if ($key == 'LSobject') {
-          if (isset($value['LSobjects']) && is_array($value['LSobjects']))
-            foreach ($value['LSobjects'] as $type)
+      $types = array();
+      $currentSubDn = LSsession :: getTopDn();
+      foreach($subdn_config as $name => $config) {
+        if ($name=='LSobject') {
+          self :: need_ldap_con();
+          if (is_array($config)) {
+            foreach($config as $objectType => $objectConf) {
+              if (LSsession :: loadLSobject($objectType)) {
+                if ($subdnobject = new $objectType()) {
+                  $tbl = $subdnobject -> getSelectArray(NULL,LSsession::getRootDn(),NULL,NULL,false,NULL,array('onlyAccessible' => False));
+                  if (is_array($tbl) && array_key_exists($currentSubDn, $tbl)) {
+                    if (is_array($objectConf['LSobjects'])) {
+                      foreach($objectConf['LSobjects'] as $type) {
+                        if (!in_array($type, $types))
+                          $types[] = $type;
+                      }
+                    }
+                    break;
+                  }
+                }
+              }
+            }
+          }
+        }
+        else if (isset($config['dn']) && $config['dn'] == $currentSubDn) {
+          if (is_array($config['LSobjects'])) {
+            foreach($config['LSobjects'] as $type) {
               if (!in_array($type, $types))
                 $types[] = $type;
-        }
-        else {
-          foreach ($value as $objConfig)
-            if (is_array($objConfig) && isset($objConfig['LSobjets']) && is_array($objConfig['LSobjects']))
-              foreach ($objConfig['LSobjects'] as $type)
-                if (!in_array($type, $types))
-                  $types[] = $type;
+            }
+          }
+          break;
         }
       }
     }
+    else {
+      $types = LSconfig :: get('LSaccess', array(), null, LSsession :: $ldapServer);
+    }
     return self :: autocomplete_opts($types, $prefix, $case_sensitive, $quote_char);
   }
 
