@@ -240,6 +240,37 @@ class LSsession {
     }
   }
 
+  /**
+	 * Log an exception via class logger
+	 *
+	 * @param[in] $exception Exception The exception to log
+	 * @param[in] $prefix string|null Custom message prefix (optional, see self :: log_exception())
+	 * @param[in] $fatal boolean Log exception as a fatal error (optional, default: true)
+	 *
+	 * @retval void
+	 **/
+	protected static function log_exception($exception, $prefix=null, $fatal=true) {
+    if (class_exists('LSlog')) {
+      LSlog :: get_logger(get_called_class()) -> exception($exception, $prefix, $fatal);
+      return;
+    }
+    // Implement basic exception message formating
+    $message = ($prefix?"$prefix :\n":"An exception occured :\n").
+      "## ".$exception->getFile().":".$exception->getLine(). " : ". $exception->getMessage();
+    self :: log(($fatal?'FATAL':'ERROR'), $message);
+  }
+
+  /**
+   * Log a message with level TRACE
+   *
+   * @param[in] $message The message to log
+   *
+   * @retval void
+   **/
+  protected static function log_trace($message) {
+    self :: log('TRACE', $message);
+  }
+
   /**
    * Log a message with level DEBUG
    *
@@ -684,12 +715,8 @@ class LSsession {
 
       LStemplate :: assign('LSsession_username',self :: getLSuserObject() -> getDisplayName());
 
-      if (isset ($_POST['LSsession_topDn']) && $_POST['LSsession_topDn']) {
-        if (self :: validSubDnLdapServer($_POST['LSsession_topDn'])) {
-          self :: $topDn = $_POST['LSsession_topDn'];
-          $_SESSION['LSsession']['topDn'] = $_POST['LSsession_topDn'];
-        } // end if
-      } // end if
+      if (isset($_POST['LSsession_topDn']) && $_POST['LSsession_topDn'])
+        self :: setSubDn($_POST['LSsession_topDn']);
 
       return true;
 
@@ -712,12 +739,11 @@ class LSsession {
 
         // topDn
         if (isset($_POST['LSsession_topDn']) && $_POST['LSsession_topDn'] != '' ){
-          self :: $topDn = $_POST['LSsession_topDn'];
+          self :: setSubDn($_POST['LSsession_topDn']);
         }
         else {
-          self :: $topDn = self :: $ldapServer['ldap_config']['basedn'];
+          self :: setSubDn(self :: $ldapServer['ldap_config']['basedn']);
         }
-        $_SESSION['LSsession_topDn']=self :: $topDn;
 
         if (!LSauth :: start()) {
           self :: log_error("startLSsession(): can't start LSauth -> stop");
@@ -767,7 +793,6 @@ class LSsession {
       if (self :: $ldapServerId) {
         LStemplate :: assign('ldapServerId',self :: $ldapServerId);
       }
-      LStemplate :: assign('topDn',self :: $topDn);
       if (isset($_GET['LSsession_recoverPassword'])) {
         self :: displayRecoverPasswordForm($recoveryPasswordInfos);
       }
@@ -829,12 +854,14 @@ class LSsession {
         $authobject = new $objType();
         $users = array_merge(
           $users,
-          $authobject -> listObjects($filter, self :: $topDn, array('onlyAccessible' => false))
+          $authobject -> listObjects($filter, self :: getTopDn(), array('onlyAccessible' => false))
         );
       }
     }
     elseif (!empty($username)) {
       $users = LSauth :: username2LSobjects($username);
+      if (!is_array($users))
+        return;
     }
     else {
       self :: log_debug('recoverPasswd(): no username or recoveryHash provided.');
@@ -1130,27 +1157,46 @@ class LSsession {
  }
 
  /**
-  * DÃ©finition du serveur Ldap de la session
+  * Set the LDAP server of the session
   *
-  * DÃ©finition du serveur Ldap de la session Ã  partir de son ID dans
-  * le tableau LSconfig :: get('ldap_servers').
+  * Set the LDAP server of the session from its ID in configuration array
+  * LSconfig :: get('ldap_servers').
   *
-  * @param[in] integer Index du serveur Ldap
+  * @param[in] $id integer Index of LDAP server
+  * @param[in] $subDn integer SubDN of LDAP server (optional)
   *
-  * @retval boolean True sinon false.
+  * @retval boolean True if set, false otherwise
   */
-  public static function setLdapServer($id) {
+  public static function setLdapServer($id, $subDn=null) {
     $conf = LSconfig :: get("ldap_servers.$id");
     if ( is_array($conf) ) {
       self :: $ldapServerId = $id;
       self :: $ldapServer = $conf;
       LSlang :: setLocale();
       self :: setGlobals();
+
+      if ($subDn)
+        return self :: setSubDn($subDn);
+
       return true;
     }
-    else {
-      return;
+    return false;
+  }
+
+ /**
+  * Set the subDn of the session
+  *
+  * @param[in] $subDn string SubDN of LDAP server
+  *
+  * @retval boolean True if set, false otherwise
+  */
+  public static function setSubDn($subDn) {
+    if (self :: validSubDnLdapServer($subDn)) {
+      self :: $topDn = $subDn;
+      $_SESSION['LSsession']['topDn'] = $subDn;
+      return true;
     }
+    return;
   }
 
  /**
@@ -1563,8 +1609,8 @@ class LSsession {
     $listTopDn = self :: getSubDnLdapServer();
     if (is_array($listTopDn)) {
       asort($listTopDn);
-      LStemplate :: assign('label_level',self :: getSubDnLabel());
-      LStemplate :: assign('_refresh',_('Refresh'));
+      LStemplate :: assign('LSsession_subDn_level',self :: getSubDnLabel());
+      LStemplate :: assign('LSsession_subDn_refresh',_('Refresh'));
       $LSsession_topDn_index = array();
       $LSsession_topDn_name = array();
       foreach($listTopDn as $index => $name) {
@@ -1920,7 +1966,7 @@ class LSsession {
               self :: log_debug("loadLSaccess(): authenticated user have no access to $objectType");
           }
         }
-        $LSaccess[self :: $topDn] = $access;
+        $LSaccess[self :: getTopDn()] = $access;
       }
     }
     if (LSauth :: displaySelfAccess()) {
@@ -1945,9 +1991,9 @@ class LSsession {
   * @retval array User's access
   **/
   public static function getLSaccess($topDn=null) {
-    if (is_null($topDn)) $topDn = self :: $topDn;
-    if (isset(self :: $LSaccess[self :: $topDn])) {
-      return self :: $LSaccess[self :: $topDn];
+    if (is_null($topDn)) $topDn = self :: getTopDn();
+    if (isset(self :: $LSaccess[$topDn])) {
+      return self :: $LSaccess[$topDn];
     }
     return array();
   }
@@ -2028,15 +2074,19 @@ class LSsession {
       $retval[] = self :: $LSuserObjectType;
 
     foreach(self :: $LSprofiles as $profile => $infos) {
-      if(self :: isLSprofile($dn,$profile)) {
-       $retval[]=$profile;
+      if(self :: isLSprofile($dn, $profile)) {
+        $retval[] = $profile;
+        self :: log_trace("whoami($dn): is '$profile'");
       }
+      else
+        self :: log_trace("whoami($dn): is NOT '$profile'");
     }
 
     if (self :: $dn == $dn) {
-      $retval[]='self';
+      $retval[] = 'self';
     }
 
+    self :: log_trace("whoami($dn): '".implode("', '", $retval)."'");
     return $retval;
   }
 
@@ -2063,6 +2113,7 @@ class LSsession {
       $whoami = self :: whoami($dn);
       if ($dn==self :: getLSuserObject() -> getValue('dn')) {
         if (!self :: in_menu('SELF')) {
+          self :: log_trace("canAccess('$LSobject', '$dn', '$right', '$attr'): SELF not in menu");
           return;
         }
       }
@@ -2070,12 +2121,14 @@ class LSsession {
         $obj = new $LSobject();
         $obj -> dn = $dn;
         if (!self :: in_menu($LSobject,$obj -> subDnValue)) {
+          self :: log_trace("canAccess('$LSobject', '$dn', '$right', '$attr'): $LSobject (for subDN='".$obj -> subDnValue."') not in menu");
           return;
         }
       }
     }
     else {
-      $objectdn=LSconfig :: get('LSobjects.'.$LSobject.'.container_dn').','.self :: $topDn;
+      $objectdn=LSconfig :: get('LSobjects.'.$LSobject.'.container_dn').','.self :: getTopDn();
+      self :: log_trace("canAccess('$LSobject', '$dn', '$right', '$attr'): use object $LSobject container DN => '$objectdn'");
       $whoami = self :: whoami($objectdn);
     }
 
@@ -2083,8 +2136,10 @@ class LSsession {
     if ($attr) {
       if ($attr=='rdn') {
         $attr=LSconfig :: get('LSobjects.'.$LSobject.'.rdn');
+        self :: log_trace("canAccess('$LSobject', '$dn', '$right', 'rdn'): RDN attribute = $attr");
       }
       if (!is_array(LSconfig :: get('LSobjects.'.$LSobject.'.attrs.'.$attr))) {
+        self :: log_warning("canAccess('$LSobject', '$dn', '$right', '$attr'): Attribute '$attr' doesn't exists");
         return;
       }
 
@@ -2100,6 +2155,7 @@ class LSsession {
           }
         }
       }
+      self :: log_trace("canAccess($LSobject,$dn,$right,$attr): right detected = '$r'");
 
       if (($right=='r')||($right=='w')) {
         if ($r==$right) {
@@ -2324,7 +2380,7 @@ class LSsession {
       if (!is_array(self :: $LSaddonsViews[$LSaddon][$viewId]['allowedLSprofiles'])) {
         return true;
       }
-      $whoami = self :: whoami(self :: $topDn);
+      $whoami = self :: whoami(self :: getTopDn());
 
       if (isset(self :: $LSaddonsViews[$LSaddon][$viewId]['allowedLSprofiles']) && is_array(self :: $LSaddonsViews[$LSaddon][$viewId]['allowedLSprofiles'])) {
         foreach($whoami as $who) {
@@ -2464,7 +2520,12 @@ class LSsession {
    * @retval boolean True si le cache des droits est activé, false sinon.
    */
   public static function cacheLSprofiles() {
-    return ( (LSconfig :: get('cacheLSprofiles')) || (self :: $ldapServer['cacheLSprofiles']) );
+    return LSconfig :: get(
+      'cacheLSprofiles',
+      LSconfig :: get('cacheLSprofiles', false, 'bool'), // Default
+      'bool',
+      self :: $ldapServer
+    );
   }
 
   /**
@@ -2475,7 +2536,12 @@ class LSsession {
    * @retval boolean True si le cache des subDn est activé, false sinon.
    */
   public static function cacheSudDn() {
-    return ( (LSconfig :: get('cacheSubDn')) || (self :: $ldapServer['cacheSubDn']));
+    return LSconfig :: get(
+      'cacheSubDn',
+      LSconfig :: get('cacheSubDn', false, 'bool'), // Default
+      'bool',
+      self :: $ldapServer
+    );
   }
 
   /**
@@ -2486,7 +2552,12 @@ class LSsession {
    * @retval boolean True si le cache des recherches est activé, false sinon.
    */
   public static function cacheSearch() {
-    return ( (LSconfig :: get('cacheSearch')) || (self :: $ldapServer['cacheSearch']));
+    return LSconfig :: get(
+      'cacheSearch',
+      LSconfig :: get('cacheSearch', false, 'bool'), // Default
+      'bool',
+      self :: $ldapServer
+    );
   }
 
   /**
@@ -2497,7 +2568,12 @@ class LSsession {
    * @retval boolean True if global search is enabled, false instead
    */
   public static function globalSearch() {
-    return LSconfig :: get('globalSearch', LSconfig :: get('globalSearch', true, 'bool'), 'bool', self :: $ldapServer);
+    return LSconfig :: get(
+      'globalSearch',
+      LSconfig :: get('globalSearch', true, 'bool'), // Default
+      'bool',
+      self :: $ldapServer
+    );
   }
 
   /**
@@ -2508,7 +2584,14 @@ class LSsession {
    * @retval string Le label des niveaux pour le serveur ldap dourant
    */
   public static function getSubDnLabel() {
-    return (self :: $ldapServer['subDnLabel']!='')?__(self :: $ldapServer['subDnLabel']):_('Level');
+    return __(
+      LSconfig :: get(
+        'subDnLabel',
+        ___('Level'), // default value (to translate)
+        'string',
+        self :: $ldapServer
+      )
+    );
   }
 
   /**
@@ -2520,11 +2603,12 @@ class LSsession {
    */
   public static function getSubDnName($subDn=false) {
     if (!$subDn) {
-      $subDn = self :: $topDn;
+      $subDn = self :: getTopDn();
     }
-    if (self :: getSubDnLdapServer(false)) {
-      if (isset(self :: $_subDnLdapServer[self :: $ldapServerId][false][$subDn])) {
-        return self :: $_subDnLdapServer[self :: $ldapServerId][false][$subDn];
+    $subDns = self :: getSubDnLdapServer(false);
+    if (is_array($subDns)) {
+      if (isset($subDns[$subDn])) {
+        return $subDns[$subDn];
       }
     }
     return '';
@@ -2556,7 +2640,7 @@ class LSsession {
    */
   public static function in_menu($LSobject,$topDn=NULL) {
     if (!$topDn) {
-      $topDn=self :: $topDn;
+      $topDn = self :: getTopDn();
     }
     return isset(self :: $LSaccess[$topDn][$LSobject]);
   }
@@ -2619,7 +2703,7 @@ class LSsession {
    */
   public static function redirectToDefaultView($force=false) {
     if (isset(self :: $ldapServer['defaultView'])) {
-      if (array_key_exists(self :: $ldapServer['defaultView'], self :: $LSaccess[self :: $topDn])) {
+      if (array_key_exists(self :: $ldapServer['defaultView'], self :: $LSaccess[self :: getTopDn()])) {
         LSurl :: redirect('object/'.self :: $ldapServer['defaultView']);
       }
       elseif (array_key_exists(self :: $ldapServer['defaultView'], self :: $LSaddonsViewsAccess)) {
@@ -2744,7 +2828,7 @@ class LSsession {
   }
 
   /**
-   * Ajax method when change ldapserver on login form
+   * Ajax method when change ldapserver on login/recoveryPassword form
    *
    * @param[in] $data array The return data address
    *
@@ -2772,20 +2856,6 @@ class LSsession {
     }
   }
 
-  /**
-   * Ajax method when change ldapserver on recoverPassword form
-   *
-   * @param[in] $data array The return data address
-   *
-   * @retval void
-   **/
-  public static function ajax_onLdapServerChangedRecoverPassword(&$data) {
-    if ( isset($_REQUEST['server']) ) {
-      self :: setLdapServer($_REQUEST['server']);
-      $data=array('recoverPassword' => isset(self :: $ldapServer['recoverPassword']));
-    }
-  }
-
   /**
    * Set globals from the ldap server
    *
